@@ -154,6 +154,9 @@ ASN1_METHOD * PROXYCERTINFO_asn1_meth();
 
 GLOBUS_DEPRECATED(
 PROXYCERTINFO * PROXYCERTINFO_dup(
+#if OPENSSL_VERSION_NUMBER >= 0x30000000L
+    const
+#endif
     PROXYCERTINFO *                     cert_info));
 
 GLOBUS_DEPRECATED(int PROXYCERTINFO_cmp(
